==> haskell-x509-1.6.5-7-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.6.5
id: x509-1.6.5-H8QS0ZpcVH5KlR9TwDe9wM
key: x509-1.6.5-H8QS0ZpcVH5KlR9TwDe9wM
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
abi: c0a74378b3a12d0b10f0047712b79436
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-1.6.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-1.6.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/x509-1.6.5
hs-libraries: HSx509-1.6.5-H8QS0ZpcVH5KlR9TwDe9wM
depends:
    asn1-encoding-0.9.5-9w4TFvLCDTrJjV3qDKgpV9
    asn1-parse-0.9.4-GrFFWUmYUno6b0yawbY5PA
    asn1-types-0.3.2-666D9GcolNS7cz58NvfKzt base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-Yx9o4pWhKT9oEOq4Ruav1
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    memory-0.14.1-2zYO5UcujuQ8oEi6uZqbHo
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pem-0.2.2-qPMQP6sZm3HgQEmiBojNt
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-1.6.5-8-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-x509.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: x509
version: 1.6.5
id: x509-1.6.5-BgKAsefughVEbw7EPM0QMy
key: x509-1.6.5-BgKAsefughVEbw7EPM0QMy
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-certificate
synopsis: X509 reader and writer
description:
    X509 reader and writer
category: Data
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Data.X509
hidden-modules: Data.X509.Internal Data.X509.CertificateChain
                Data.X509.AlgorithmIdentifier Data.X509.DistinguishedName
                Data.X509.Cert Data.X509.PublicKey Data.X509.PrivateKey
                Data.X509.Ext Data.X509.ExtensionRaw Data.X509.CRL Data.X509.OID
                Data.X509.Signed
abi: 04e9a0af3553f07fb4315035e854d736
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/x509-1.6.5
library-dirs: /usr/lib/ghc-8.0.1/site-local/x509-1.6.5
data-dir: /usr/share/arm-linux-ghc-8.0.1/x509-1.6.5
hs-libraries: HSx509-1.6.5-BgKAsefughVEbw7EPM0QMy
depends:
    asn1-encoding-0.9.5-KEv9oQIytIt80KsOUoTGaP
    asn1-parse-0.9.4-AueoU8NRlssVLAoi6TNzh
    asn1-types-0.3.2-GaKqhjzvrVE1bhI34X9Z4G base-4.9.0.0
    bytestring-0.10.8.1 containers-0.5.7.1
    cryptonite-0.22-7bAfM4r9KLCJIhVfr7jYAd
    hourglass-0.2.10-I8h0J4RSF89FN6CuD9x2Xx
    memory-0.14.2-6gBSLDcT37k2vocvCRPqMi
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM pem-0.2.2-qPMQP6sZm3HgQEmiBojNt
haddock-interfaces: /usr/share/doc/haskell-x509/html/x509.haddock
haddock-html: /usr/share/doc/haskell-x509/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
